@@ -1,14 +1,13 @@
 #include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
-
-#include <libgnomevfs/gnome-vfs-mime.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <libgnomeui/gnome-ui-init.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-directory.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "menu-ditem.h"
@@ -23,7 +22,7 @@ GSList *panel_applet_list_applets (void) { return NULL; }
 static int dialogs = 0;
 static gboolean create_new = FALSE;
 
-struct poptOption options [] = {
+static struct poptOption options [] = {
 	{ "create-new", '\0', POPT_ARG_NONE,
 	  &create_new, 0, N_("Create new file in the given directory"), NULL },
         POPT_AUTOHELP
@@ -80,6 +79,10 @@ main (int argc, char * argv[])
 	int i;
 	GnomeVFSFileInfo *info;
 
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	program = gnome_program_init ("gnome-desktop-item-edit", VERSION,
 				      LIBGNOMEUI_MODULE,
 				      argc, argv,
@@ -89,6 +92,8 @@ main (int argc, char * argv[])
 		      GNOME_PARAM_POPT_CONTEXT, &ctx,
 		      NULL);
 
+	gtk_window_set_default_icon_name ("launcher-program");
+
 	desktops = (char **)poptGetArgs (ctx);
 
 	if (desktops == NULL ||
