@@ -406,6 +406,7 @@ panel_properties_dialog_setup_image_chooser (PanelPropertiesDialog *dialog,
 	GtkFileFilter *filter;
 	char          *image;
 
+	//TODO add a preview widget
 	dialog->image_chooser = glade_xml_get_widget (gui, "image_chooser");
 
 	filter = gtk_file_filter_new ();
@@ -418,11 +419,14 @@ panel_properties_dialog_setup_image_chooser (PanelPropertiesDialog *dialog,
 
 	image = panel_profile_get_background_image (dialog->toplevel);
 
-	if (image) {
+	if (string_empty (image))
+		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (dialog->image_chooser));
+	else
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog->image_chooser),
 					       image);
+	
+	if (image)
 		g_free (image);
-	}
 
 	g_signal_connect_swapped (dialog->image_chooser, "selection-changed",
 				  G_CALLBACK (panel_properties_dialog_image_changed),
@@ -664,6 +668,8 @@ panel_properties_dialog_toplevel_notify (GConfClient           *client,
 	const char *key;
 
 	key = panel_gconf_basename (gconf_entry_get_key (entry));
+	if (!key)
+		return;
 
 	value = gconf_entry_get_value (entry);
 
@@ -770,11 +776,14 @@ panel_properties_dialog_update_background_image (PanelPropertiesDialog *dialog,
 	text = gconf_value_get_string (value);
 	old_text = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog->image_chooser));
 
-	if (text && (!old_text || strcmp (text, old_text)))
+	if (string_empty (text) && old_text)
+		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (dialog->image_chooser));
+	else if (!string_empty (text) && (!old_text || strcmp (text, old_text)))
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog->image_chooser),
 					       text);
 
-	g_free (old_text);
+	if (old_text)
+		g_free (old_text);
 }
 
 static void
@@ -787,6 +796,8 @@ panel_properties_dialog_background_notify (GConfClient           *client,
 	const char *key;
 
 	key = panel_gconf_basename (gconf_entry_get_key (entry));
+	if (!key)
+		return;
 
 	value = gconf_entry_get_value (entry);
 
@@ -966,6 +977,14 @@ panel_properties_dialog_present (PanelToplevel *toplevel)
 	gui = glade_xml_new (GLADEDIR "/panel-properties-dialog.glade",
 			     "panel_properties_dialog",
 			     NULL);
+	if (gui == NULL) {
+		panel_error_dialog (gtk_window_get_screen (GTK_WINDOW (toplevel)),
+				    "cannot_display_properties_dialog", TRUE,
+				    _("Cannot Display Properties Dialog"),
+				    _("%s could not be loaded."),
+				    GLADEDIR "/panel-properties-dialog.glade");
+		return;
+	}
 
 	dialog = panel_properties_dialog_new (toplevel, gui);
 
