@@ -1322,8 +1322,6 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	GList *list;
 	int i;
 	int old_size;
-	int old_thick;
-	GtkAllocation old_alloc;
 
 	g_return_if_fail(PANEL_IS_WIDGET(widget));
 	g_return_if_fail(allocation!=NULL);
@@ -1331,10 +1329,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	panel = PANEL_WIDGET(widget);
 
 	old_size = panel->size;
-	old_thick = panel->thick;
 	
-	old_alloc = widget->allocation;
-
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
 		gdk_window_move_resize (widget->window,
@@ -1673,10 +1668,14 @@ panel_widget_destroy (GtkObject *obj)
 
 	panel_widget_destroy_open_dialogs (panel);
 
-	if (panel->master_widget != NULL)
+	if (panel->master_widget != NULL) {
 		g_object_set_data (G_OBJECT (panel->master_widget),
 				   PANEL_APPLET_ASSOC_PANEL_KEY,
 				   NULL);
+		g_object_remove_weak_pointer (G_OBJECT (panel->master_widget),
+					      (gpointer *) &panel->master_widget);
+		panel->master_widget = NULL;
+	}
 
 	if (GTK_OBJECT_CLASS (panel_widget_parent_class)->destroy)
 		GTK_OBJECT_CLASS (panel_widget_parent_class)->destroy (obj);
@@ -1822,11 +1821,12 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 	g_message("Starting drag [grabbed] on a %s at %p\n",
 		  g_type_name(G_TYPE_FROM_INSTANCE(applet)), applet);
 #endif
-	panel_toplevel_block_auto_hide (panel->toplevel);
 
 	if (!panel_widget_applet_drag_start_no_grab (panel, applet, drag_off))
 		return;
 
+	panel_toplevel_push_autohide_disabler (panel->toplevel);
+
 	gtk_grab_add (applet);
 	if (applet->window) {
 		GdkGrabStatus  status;
@@ -1859,7 +1859,7 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 	gdk_pointer_ungrab (GDK_CURRENT_TIME);
 	gtk_grab_remove (panel->currently_dragged_applet->applet);
 	panel_widget_applet_drag_end_no_grab (panel);
-	panel_toplevel_unblock_auto_hide (panel->toplevel);
+	panel_toplevel_pop_autohide_disabler (panel->toplevel);
 	gdk_flush ();
 }
 
@@ -2005,9 +2005,6 @@ panel_widget_nice_move (PanelWidget *panel,
 			AppletData  *ad,
 			int          pos)
 {
-	AppletData *pad1 = NULL, *pad2 = NULL;
-	GList      *l;
-	
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 	g_return_if_fail (ad != NULL);
 
@@ -2015,22 +2012,12 @@ panel_widget_nice_move (PanelWidget *panel,
 	if (pos < 0 || pos == ad->pos)
 		return;
 
-	l = g_list_find (panel->applet_list, ad);
-	if (l && l->prev) {
-		pad1 = l->prev->data;
-	}
-
 	ad->pos = ad->constrained = pos;
 
 	panel->applet_list =
 		panel_g_list_resort_item (panel->applet_list, ad,
 					  (GCompareFunc)applet_data_compare);
 
-	l = g_list_find (panel->applet_list, ad);
-	if (l && l->prev) {
-		pad2 = l->prev->data;
-	}
-
 	gtk_widget_queue_resize (GTK_WIDGET (panel));
 
 	emit_applet_moved (panel, ad);
@@ -2242,13 +2229,16 @@ panel_widget_applet_button_release_event (GtkWidget      *widget,
 }
 
 static gboolean
-panel_widget_applet_motion_notify_event (GtkWidget      *widget,
-					 GdkEventMotion *event)
+panel_widget_applet_motion_notify_event (GtkWidget *widget,
+					 GdkEvent  *event)
 {
 	PanelWidget *panel;
 	
 	g_return_val_if_fail (PANEL_IS_WIDGET (widget->parent), FALSE);
 
+	if (gdk_event_get_screen (event) != gtk_widget_get_screen (widget))
+		return FALSE;
+
 	panel = PANEL_WIDGET (widget->parent);
 	
 	schedule_try_move (panel, FALSE);
@@ -2335,6 +2325,7 @@ panel_widget_applet_destroy (GtkWidget *applet, gpointer data)
 	g_return_if_fail (GTK_IS_WIDGET (applet));
 
 	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
+	g_object_set_data (G_OBJECT (applet), PANEL_APPLET_DATA, NULL);
 
 	/*if it wasn't yet removed*/
 	if(applet->parent) {
@@ -2360,7 +2351,6 @@ bind_top_applet_events (GtkWidget *widget)
 			  G_CALLBACK (panel_widget_applet_destroy),
 			  NULL);
 
-	/* connect-after so that we stop the propogation of the event */
 	g_signal_connect (widget, "button-press-event",
 			  G_CALLBACK (panel_widget_applet_button_press_event),
 			  NULL);
@@ -2637,6 +2627,7 @@ panel_widget_background_changed (PanelBackground *background,
 				 PanelWidget     *panel)
 {
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
+	panel_toplevel_update_edges (panel->toplevel);
 	g_signal_emit (G_OBJECT (panel),
 		       panel_widget_signals [BACK_CHANGE_SIGNAL],
 		       0);
@@ -2918,7 +2909,7 @@ panel_widget_toggle_applet_locked (PanelWidget *panel,
 }
 
 gboolean
-panel_applet_is_in_drag ()
+panel_applet_is_in_drag (void)
 {
 	return panel_applet_in_drag;
 }
